@@ -9,7 +9,6 @@ pub mod test {
         pub id: i32,
         #[cmd(default("123123"))]
         pub name: String,
-        pub child: Weak<Foo2>
     }
 
     #[derive(build, Debug)]
@@ -29,7 +28,6 @@ pub mod test {
 
 use xxlib::*;
 use test::*;
-use sharedptr::unsafe_def::IGetMutUnchecked;
 
 #[test]
 pub fn test()->anyhow::Result<()>{
@@ -44,9 +42,6 @@ pub fn test()->anyhow::Result<()>{
     foo2.base=SharedPtr::new(foo);
 
     let foo2_ptr=SharedPtr::new(foo2);
-    unsafe {
-        foo2_ptr.base.get_mut_unchecked().child = foo2_ptr.weak().ok_or_else(|| anyhow::anyhow!("is none"))?;
-    }
 
     let mut data=Data::new();
     let om=ObjectManager::new();
@@ -59,7 +54,6 @@ pub fn test()->anyhow::Result<()>{
     assert_eq!(foo2_ptr.id,ptr.id);
     assert_eq!(foo2_ptr.base.id,ptr.base.id);
     assert_eq!(foo2_ptr.base.name,ptr.base.name);
-    assert_eq!(foo2_ptr.id,ptr.base.child.upgrade().ok_or_else(||anyhow::anyhow!("none"))?.id);
 
     let x= filter_ids("Foo");
     assert_eq!(x,&[106,107]);
